package com.ruoyi.powerdistribution.service;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmDic;

/**
 * 配网字典Service接口
 * 
 * @author ruoyi
 * @date 2024-12-03
 */
public interface IPdmDicService 
{
    /**
     * 查询配网字典
     * 
     * @param id 配网字典主键
     * @return 配网字典
     */
    public PdmDic selectPdmDicById(Long id);

    /**
     * 查询配网字典列表
     * 
     * @param pdmDic 配网字典
     * @return 配网字典集合
     */
    public List<PdmDic> selectPdmDicList(PdmDic pdmDic);

    /**
     * 新增配网字典
     * 
     * @param pdmDic 配网字典
     * @return 结果
     */
    public int insertPdmDic(PdmDic pdmDic);

    /**
     * 修改配网字典
     * 
     * @param pdmDic 配网字典
     * @return 结果
     */
    public int updatePdmDic(PdmDic pdmDic);

    /**
     * 批量删除配网字典
     * 
     * @param ids 需要删除的配网字典主键集合
     * @return 结果
     */
    public int deletePdmDicByIds(Long[] ids);

    /**
     * 删除配网字典信息
     * 
     * @param id 配网字典主键
     * @return 结果
     */
    public int deletePdmDicById(Long id);

    public List<PdmDic> getPdmDicTree( );
}
